# NOT RUN {
# Get a copy of the profile of lints from the purrr package
data("style_purrr")
# Get the path to a file to check
path <- system.file("extdata", 'styles.R', package='adaptalint')
# Check this file against the lint profile of purrr
lint_with_style(filename = path, style = style_purrr)
# }
Run the code above in your browser using DataLab