Learn R Programming

adaptalint (version 0.2.4)

style_plyr: A style extracted from a popular package, included for convenience

Description

A style extracted from a popular package, included for convenience

Usage

style_plyr

Arguments

Format

An object of class tbl_df (inherits from tbl, data.frame) with 7 rows and 4 columns.

See Also

Other bundled_styles: style_adaptalint, style_dplyr, style_fbar, style_gsheet, style_purrr, style_tidyr